#
# spec file for package ghc-warp
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name warp
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        3.3.19
Release:        bp154.1.15
Summary:        A fast, light-weight web server for WAI applications
License:        MIT
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-array-devel
BuildRequires:  ghc-auto-update-devel
BuildRequires:  ghc-bsb-http-chunked-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-case-insensitive-devel
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-hashable-devel
BuildRequires:  ghc-http-date-devel
BuildRequires:  ghc-http-types-devel
BuildRequires:  ghc-http2-devel
BuildRequires:  ghc-iproute-devel
BuildRequires:  ghc-network-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-simple-sendfile-devel
BuildRequires:  ghc-stm-devel
BuildRequires:  ghc-streaming-commons-devel
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-time-manager-devel
BuildRequires:  ghc-unix-compat-devel
BuildRequires:  ghc-unix-devel
BuildRequires:  ghc-unliftio-devel
BuildRequires:  ghc-vault-devel
BuildRequires:  ghc-wai-devel
BuildRequires:  ghc-word8-devel
BuildRequires:  ghc-x509-devel
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-HUnit-devel
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-async-devel
BuildRequires:  ghc-directory-devel
BuildRequires:  ghc-hspec-devel
BuildRequires:  ghc-http-client-devel
BuildRequires:  ghc-process-devel
BuildRequires:  ghc-time-devel
%endif

%description
HTTP/1.0, HTTP/1.1 and HTTP/2 are supported. For HTTP/2, Warp supports direct
and ALPN (in TLS) but not upgrade. API docs and the README are available at
<http://www.stackage.org/package/warp>.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc ChangeLog.md README.md

%changelog
* Wed Feb  2 2022 Peter Simons <psimons@suse.com>
- Update warp to version 3.3.19.
  [#]# 3.3.19
  * Allowing the eMFILE exception in acceptNewConnection.
    [#831](https://github.com/yesodweb/wai/pull/831)
* Sat Nov 20 2021 psimons@suse.com
- Update warp to version 3.3.18.
  [#]# 3.3.18
  * Tidy up HashMap and MultiMap [#864](https://github.com/yesodweb/wai/pull/864)
  * Support GHC 9.2 [#863](https://github.com/yesodweb/wai/pull/863)
* Tue Jun 22 2021 psimons@suse.com
- Update warp to version 3.3.17.
  [#]# 3.3.17
  * Modify exception handling to swallow async exceptions in forked thread [#850](https://github.com/yesodweb/wai/issues/850)
  * Switch default forking function to not install the global exception handler (minor optimization) [#851](https://github.com/yesodweb/wai/pull/851)
* Wed May 26 2021 psimons@suse.com
- Update warp to version 3.3.16.
  [#] ChangeLog for warp
  [#]# 3.3.16
  * Move exception handling over to `unliftio` for better async exception support [#845](https://github.com/yesodweb/wai/issues/845)
* Fri Apr 16 2021 psimons@suse.com
- Update warp to version 3.3.15.
  [#]# 3.3.15
  * Using http2 v3.
* Thu Feb  4 2021 psimons@suse.com
- Update warp to version 3.3.14.
  [#]# 3.3.14
  * Drop support for GHC < 8.2.
  * Fix header length calculation for `settingsMaxTotalHeaderLength`
    [#838](https://github.com/yesodweb/wai/pull/838)
  * UTF-8 encoding in `exceptionResponseForDebug`.
    [#836](https://github.com/yesodweb/wai/pull/836)
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Fri Jun 26 2020 psimons@suse.com
- Update warp to version 3.3.13.
  [#]# 3.3.13
  * pReadMaker is exported from the Internal module.
* Tue Jun  9 2020 psimons@suse.com
- Add warp at version 3.3.12.
